@@ -1,10 +1,10 @@
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2009-2017 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -13,10 +13,9 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 
 
 #include <math.h>
@@ -25,16 +24,16 @@
 
 Rlinctl::Rlinctl (X_window   *parent,
                   X_callback *cbobj,
-                  RotaryImg  *image,
-                  int        xp,
-                  int        yp,
-		  int        cm,
-		  int        dd,
-                  double     vmin,
-	          double     vmax,
-	          double     vini,
-                  int        cbind) :
-RotaryCtl (parent, cbobj, image, xp, yp, cbind),
+		  int         cbind,
+                  RotaryGeom *geom,
+                  int         xp,
+                  int         yp,
+		  int         cm,
+		  int         dd,
+                  double      vmin,
+	          double      vmax,
+	          double      vini) :
+RotaryCtl (parent, cbobj, cbind, geom, xp, yp),
 _cm (cm),
 _dd (dd),
 _vmin (vmin),
@@ -91,16 +90,16 @@ int Rlinctl::set_count (int u)
 
 Rlogctl::Rlogctl (X_window   *parent,
                   X_callback *cbobj,
-                  RotaryImg  *image,
-                  int        xp,
-                  int        yp,
-		  int        cm,
-		  int        dd,
-                  double     vmin,
-	          double     vmax,
-	          double     vini,
-                  int        cbind) :
-RotaryCtl (parent, cbobj, image, xp, yp, cbind),
+		  int         cbind,
+                  RotaryGeom *geom,
+                  int         xp,
+                  int         yp,
+		  int         cm,
+		  int         dd,
+                  double      vmin,
+	          double      vmax,
+	          double      vini) :
+RotaryCtl (parent, cbobj, cbind, geom, xp, yp),
 _cm (cm),
 _dd (dd),
 _form (0)
