@@ -1,10 +1,10 @@
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2009-2017 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -13,10 +13,9 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 
 
 #include <stdlib.h>
@@ -54,20 +53,20 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jc
     _ambis = xres->getb (".ambisonic", false);
     RotaryCtl::init (disp ());
     x = 0;
-    _rotary [R_DELAY] = new Rlinctl (this, this, &r_delay_img, x, 0, 160, 5,  0.02,  0.100,  0.04, R_DELAY);
-    _rotary [R_XOVER] = new Rlogctl (this, this, &r_xover_img, x, 0, 200, 5,  50.0, 1000.0, 200.0, R_XOVER);
-    _rotary [R_RTLOW] = new Rlogctl (this, this, &r_rtlow_img, x, 0, 200, 5,   1.0,    8.0,   3.0, R_RTLOW);
-    _rotary [R_RTMID] = new Rlogctl (this, this, &r_rtmid_img, x, 0, 200, 5,   1.0,    8.0,   2.0, R_RTMID);
-    _rotary [R_FDAMP] = new Rlogctl (this, this, &r_fdamp_img, x, 0, 200, 5, 1.5e3, 24.0e3, 6.0e3, R_FDAMP);
+    _rotary [R_DELAY] = new Rlinctl (this, this, R_DELAY, &r_delay, x, 0, 160, 5,  0.02,  0.100,  0.04);
+    _rotary [R_XOVER] = new Rlogctl (this, this, R_XOVER, &r_xover, x, 0, 200, 5,  50.0, 1000.0, 200.0);
+    _rotary [R_RTLOW] = new Rlogctl (this, this, R_RTLOW, &r_rtlow, x, 0, 200, 5,   1.0,    8.0,   3.0);
+    _rotary [R_RTMID] = new Rlogctl (this, this, R_RTMID, &r_rtmid, x, 0, 200, 5,   1.0,    8.0,   2.0);
+    _rotary [R_FDAMP] = new Rlogctl (this, this, R_FDAMP, &r_fdamp, x, 0, 200, 5, 1.5e3, 24.0e3, 6.0e3);
     x += 315;
-    _rotary [R_EQ1FR] = new Rlogctl (this, this, &r_parfr_img, x, 0, 180, 5,  40.0,  2.5e3, 160.0, R_EQ1FR);
-    _rotary [R_EQ1GN] = new Rlinctl (this, this, &r_pargn_img, x, 0, 150, 5, -15.0,   15.0,   0.0, R_EQ1GN);
+    _rotary [R_EQ1FR] = new Rlogctl (this, this, R_EQ1FR, &r_parfr, x, 0, 180, 5,  40.0,  2.5e3, 160.0);
+    _rotary [R_EQ1GN] = new Rlinctl (this, this, R_EQ1GN, &r_pargn, x, 0, 150, 5, -15.0,   15.0,   0.0);
     x += 110;
-    _rotary [R_EQ2FR] = new Rlogctl (this, this, &r_parfr_img, x, 0, 180, 5, 160.0,   10e3, 2.5e3, R_EQ2FR);
-    _rotary [R_EQ2GN] = new Rlinctl (this, this, &r_pargn_img, x, 0, 150, 5, -15.0,   15.0,   0.0, R_EQ2GN);
+    _rotary [R_EQ2FR] = new Rlogctl (this, this, R_EQ2FR, &r_parfr, x, 0, 180, 5, 160.0,   10e3, 2.5e3);
+    _rotary [R_EQ2GN] = new Rlinctl (this, this, R_EQ2GN, &r_pargn, x, 0, 150, 5, -15.0,   15.0,   0.0);
     x += 110;
-    _rotary [R_OPMIX] = new Rlinctl (this, this, &r_opmix_img, x, 0, 180, 5,   0.0 ,   1.0,   0.5, R_OPMIX);
-    _rotary [R_RGXYZ] = new Rlinctl (this, this, &r_rgxyz_img, x, 0, 180, 5,  -9.0 ,   9.0,   0.0, R_RGXYZ);
+    _rotary [R_OPMIX] = new Rlinctl (this, this, R_OPMIX, &r_opmix, x, 0, 180, 5,   0.0 ,   1.0,   0.5);
+    _rotary [R_RGXYZ] = new Rlinctl (this, this, R_RGXYZ, &r_rgxyz, x, 0, 180, 5,  -9.0 ,   9.0,   0.0);
     for (i = 0; i < R_OPMIX; i++) _rotary [i]->x_map ();
     if (_ambis) _rotary [R_RGXYZ]->x_map ();
     else        _rotary [R_OPMIX]->x_map ();
