@@ -1,10 +1,10 @@
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2009-2017 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -13,10 +13,9 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 
 
 #ifndef __STYLES_H
@@ -29,13 +28,11 @@
 enum
 {
     C_MAIN_BG, C_MAIN_FG,
-//    C_TEXT_BG, C_TEXT_FG,
     NXFTCOLORS
 };
 
 enum
 {
-//    F_TEXT, F_FILE,
     NXFTFONTS
 };
 
@@ -55,15 +52,15 @@ extern XImage    *mixsect_img;
 extern XImage    *ambsect_img;
 extern XImage    *redzita_img;
 
-extern RotaryImg  r_delay_img;
-extern RotaryImg  r_xover_img;
-extern RotaryImg  r_rtlow_img;
-extern RotaryImg  r_rtmid_img;
-extern RotaryImg  r_fdamp_img;
-extern RotaryImg  r_parfr_img;
-extern RotaryImg  r_pargn_img;
-extern RotaryImg  r_opmix_img;
-extern RotaryImg  r_rgxyz_img;
+extern RotaryGeom  r_delay;
+extern RotaryGeom  r_xover;
+extern RotaryGeom  r_rtlow;
+extern RotaryGeom  r_rtmid;
+extern RotaryGeom  r_fdamp;
+extern RotaryGeom  r_parfr;
+extern RotaryGeom  r_pargn;
+extern RotaryGeom  r_opmix;
+extern RotaryGeom  r_rgxyz;
 
 
 #endif
